# PhoneNumberType

None

URI: http://www.w3.org/2001/XMLSchema#string

* [base](https://w3id.org/linkml/base): str



* [pattern](https://w3id.org/linkml/pattern): `^[\\+\\d+ +][\\d\\- ]+$`



## Identifier and Mapping Information


